.. _traversal_module:

:mod:`pyramid.traversal`
---------------------------

.. automodule:: pyramid.traversal

  .. autofunction:: find_interface

  .. autofunction:: find_resource

  .. autofunction:: find_root

  .. autofunction:: resource_path

  .. autofunction:: resource_path_tuple

  .. autofunction:: quote_path_segment

  .. autofunction:: virtual_root

  .. autofunction:: traverse

  .. autofunction:: traversal_path(path)

